@@ -1,11 +1,12 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import random
 import warnings
 from collections.abc import Sequence
-from distutils.version import LooseVersion
 
 import cv2
 import mmcv
 import numpy as np
+from mmcv.utils import digit_version
 from torch.nn.modules.utils import _pair
 
 from ..builder import PIPELINES
@@ -68,7 +69,7 @@ class TorchvisionTrans:
             import torchvision.transforms as tv_trans
         except ImportError:
             raise RuntimeError('Install torchvision to use TorchvisionTrans')
-        if LooseVersion(torchvision.__version__) < LooseVersion('0.8.0'):
+        if digit_version(torchvision.__version__) < digit_version('0.8.0'):
             raise RuntimeError('The version of torchvision should be at least '
                                '0.8.0')
 
@@ -105,7 +106,7 @@ class PytorchVideoTrans:
             import pytorchvideo.transforms as ptv_trans
         except ImportError:
             raise RuntimeError('Install pytorchvideo to use PytorchVideoTrans')
-        if LooseVersion(torch.__version__) < LooseVersion('1.8.0'):
+        if digit_version(torch.__version__) < digit_version('1.8.0'):
             raise RuntimeError(
                 'The version of PyTorch should be at least 1.8.0')
 
@@ -715,7 +716,7 @@ class RandomCrop:
         new_crop_quadruple = [
             old_x_ratio + x_ratio * old_w_ratio,
             old_y_ratio + y_ratio * old_h_ratio, w_ratio * old_w_ratio,
-            h_ratio * old_x_ratio
+            h_ratio * old_h_ratio
         ]
         results['crop_quadruple'] = np.array(
             new_crop_quadruple, dtype=np.float32)
@@ -878,7 +879,7 @@ class RandomResizedCrop(RandomCrop):
         new_crop_quadruple = [
             old_x_ratio + x_ratio * old_w_ratio,
             old_y_ratio + y_ratio * old_h_ratio, w_ratio * old_w_ratio,
-            h_ratio * old_x_ratio
+            h_ratio * old_h_ratio
         ]
         results['crop_quadruple'] = np.array(
             new_crop_quadruple, dtype=np.float32)
@@ -1059,7 +1060,7 @@ class MultiScaleCrop(RandomCrop):
         new_crop_quadruple = [
             old_x_ratio + x_ratio * old_w_ratio,
             old_y_ratio + y_ratio * old_h_ratio, w_ratio * old_w_ratio,
-            h_ratio * old_x_ratio
+            h_ratio * old_h_ratio
         ]
         results['crop_quadruple'] = np.array(
             new_crop_quadruple, dtype=np.float32)
@@ -1676,7 +1677,7 @@ class CenterCrop(RandomCrop):
         new_crop_quadruple = [
             old_x_ratio + x_ratio * old_w_ratio,
             old_y_ratio + y_ratio * old_h_ratio, w_ratio * old_w_ratio,
-            h_ratio * old_x_ratio
+            h_ratio * old_h_ratio
         ]
         results['crop_quadruple'] = np.array(
             new_crop_quadruple, dtype=np.float32)
